#ifndef CLOUDPROVIDERS_H
#define CLOUDPROVIDERS_H

#define CLOUDPROVIDERS_INSIDE
#include "enums.h"
#include "cloudprovidersaccount.h"
#include "cloudprovidersaccountexporter.h"
#include "cloudproviderscollector.h"
#include "cloudprovidersprovider.h"
#include "cloudprovidersproviderexporter.h"
#undef CLOUDPROVIDERS_INSIDE

#endif // CLOUDPROVIDERS_H
